HAL_9000 may not be the best deep learning framework, but it is a deep learning framework.

To install the library:

    pip install HAL-9000

Workflow of this framework is inspired by Tensorflow’s Keras.

As of now, HAL_9000 offers:

7 different variants of NNs:

    -> Perceptron
    -> Multilayer Perceptron
    -> Dense Net
    -> Conv Net
    -> Vanilla RNN
    -> LSTM
    -> DQN

Several regularization methods:

    -> Batch Norm
    -> Layer Norm
    -> Dropout

Optimizers:

    -> Adam
    -> RMS prop
    -> SGD
    
for more info and examples, visit: https://github.com/kumar-harin/HAL_9000